<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-revisions?lang_cible=en
// ** ne pas modifier le fichier **

return [

	// R
	'revisions_description' => 'Tracking changes of editorial objects',
	'revisions_slogan' => 'Tracking changes of editorial objects',
];
